@@ -54,7 +54,7 @@ PY_TO_JSON_TYPES_MAP = {
     set: {"type": "array"},
     tuple: {"type": "array"},
     float: {"type": "number", "format": "float"},
-    int: {"type": "number", "format": "integer"},
+    int: {"type": "integer"},
     bool: {"type": "boolean"},
     Enum: {"type": "string"},
 }
@@ -86,6 +86,7 @@ MARSHMALLOW_TO_PY_TYPES_PAIRS = [
     (fields.List, list),
     (fields.Number, decimal.Decimal),
     (fields.IP, str),
+    (fields.IPInterface, str),
     # This one is here just for completeness sake and to check for
     # unknown marshmallow fields more cleanly.
     (fields.Nested, dict),
@@ -187,7 +188,7 @@ class JSONSchema(Schema):
         if field.dump_only:
             json_schema["readOnly"] = True
 
-        if field.default is not missing:
+        if field.default is not missing and not callable(field.default):
             json_schema["default"] = field.default
 
         if ALLOW_ENUMS and isinstance(field, EnumField):
@@ -324,6 +325,9 @@ class JSONSchema(Schema):
                 continue
             schema[md_key] = md_val
 
+        if field.default is not missing and not callable(field.default):
+            schema["default"] = nested_instance.dump(field.default)
+
         if field.many:
             schema = {
                 "type": "array" if field.required else ["array", "null"],
